# mini-groove

Just a little learning experiment with Rust. The goal was to make a simple geospatial Rust/Python library (installable from [PyPI](https://pypi.org/project/mini-groove/)). Thanks to the great utilities by [GeoRust](https://github.com/georust) and [PyO3/maturin](https://github.com/PyO3/maturin), it was not hard at all (so far). To be continued (or not)...

The library can be used for smoothing and simplifying polygon geometries (from GeoJSON or WKT). Benchmarking is yet to be done, but it seems to be reasonably fast already. 
